==> minter-android-blockchain-testnet-0.13.0-sources.jar: network/minter/blockchain/models/Coin.java <==
/*
 * Copyright (C) by MinterTeam. 2020
 * @link <a href="https://github.com/MinterTeam">Org Github</a>
 * @link <a href="https://github.com/edwardstock">Maintainer Github</a>
 *
 * The MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package network.minter.blockchain.models;

import com.google.gson.annotations.SerializedName;

import org.parceler.Parcel;

import java.math.BigDecimal;
import java.math.BigInteger;

import network.minter.blockchain.models.operational.Transaction;

/**
 * minter-android-blockchain. 2018
 *
 * @author Eduard Maximovich <edward.vstock@gmail.com>
 */
@Parcel
public class Coin {
    public String name;
    public String symbol;
    public BigInteger volume;
    public int crr;
    @SerializedName("reserve_balance")
    public BigInteger reserveBalance;
    @SerializedName("max_supply")
    public BigInteger maxSupply;

    public String getSymbol() {
        return symbol.toUpperCase();
    }

    public BigDecimal getReserveBalance() {
        return Transaction.humanizeValue(reserveBalance);
    }

    public double getReserveBalanceDouble() {
        return getReserveBalance().doubleValue();
    }
}

==> minter-android-blockchain-testnet-1.0.1-sources.jar: network/minter/blockchain/models/Coin.java <==
/*
 * Copyright (C) by MinterTeam. 2020
 * @link <a href="https://github.com/MinterTeam">Org Github</a>
 * @link <a href="https://github.com/edwardstock">Maintainer Github</a>
 *
 * The MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package network.minter.blockchain.models;

import com.google.gson.annotations.SerializedName;

import org.parceler.Parcel;

import java.math.BigDecimal;
import java.math.BigInteger;

import network.minter.blockchain.models.operational.Transaction;
import network.minter.core.crypto.MinterAddress;

/**
 * minter-android-blockchain. 2020
 * @author Eduard Maximovich <edward.vstock@gmail.com>
 */
@Parcel
public class Coin extends NodeResult {
    public BigInteger id;
    public String name;
    public String symbol;
    public BigInteger volume;
    public int crr;
    @SerializedName("reserve_balance")
    public BigInteger reserveBalance;
    @SerializedName("max_supply")
    public BigInteger maxSupply;
    @SerializedName("owner_address")
    public MinterAddress owner;

    public String getSymbol() {
        return symbol.toUpperCase();
    }

    public BigDecimal getReserveBalance() {
        return Transaction.humanizeValue(reserveBalance);
    }

    public double getReserveBalanceDouble() {
        return getReserveBalance().doubleValue();
    }
}
